pub enum BatchHandoffError {
QueryOutputSetup {
source: DataFusionError,
stats: BatchHandoffStats,
},
Upstream {
source: DataFusionError,
stats: BatchHandoffStats,
},
Downstream {
source: DeltaFunnelError,
stats: BatchHandoffStats,
},
}Expand description
Terminal failure from a query-output handoff.
Upstream errors come from the DataFusion stream. Downstream errors come from
the batch consumer, which will later be backed by arrow-tiberius.
Variants
QueryOutputSetup
The selected DataFusion query output could not be exposed as a stream.
Fields
source: DataFusionErrorOriginal DataFusion setup error.
stats: BatchHandoffStatsHandoff counters for batches accepted before the failure.
Upstream
The upstream DataFusion stream failed before producing the next batch.
Fields
source: DataFusionErrorOriginal DataFusion error with its existing provider/query context.
stats: BatchHandoffStatsHandoff counters for batches accepted before the failure.
Downstream
The downstream consumer rejected the current batch.
Fields
source: DeltaFunnelErrorOriginal downstream writer error.
stats: BatchHandoffStatsHandoff counters for batches accepted before the failure.
Implementations
Sourceimpl BatchHandoffError
impl BatchHandoffError
Sourcepub fn stats(&self) -> BatchHandoffStats
pub fn stats(&self) -> BatchHandoffStats
Returns counters for batches accepted before the terminal failure.