pub enum LoadMode {
AppendExisting,
CreateAndLoad,
Replace,
}Expand description
SQL Server table lifecycle mode requested for one selected output.
Variants
AppendExisting
Write rows into an already existing target table.
CreateAndLoad
Plan a target table definition and then load rows into the new table.
Replace
Write rows to a staging table, validate them, then swap it into the target name.