pub enum MssqlTargetCleanupStatus {
NotApplicable,
NotAttempted,
Succeeded,
Failed,
}Expand description
Cleanup reporting state for a SQL Server target owned by create-and-load.
Variants
NotApplicable
No cleanup is owned by this output, such as append-existing mode.
NotAttempted
Cleanup would be owned by this output, but the target was not created.
Succeeded
Cleanup was required, attempted, and succeeded.
Failed
Cleanup was required, attempted, and failed.