pub enum MssqlTargetTableState {
Exists,
Absent,
ExistsOrAbsent,
}Expand description
Expected live state of the target table before loading starts.
Variants
Exists
Target table should already exist before loading.
Absent
Target table should not exist before loading and should be created.
ExistsOrAbsent
Target table may already exist or may be created by this lifecycle.