pub enum PhaseStatus {
Completed,
Failed,
Skipped {
reason: ReportReasonCode,
},
NotStarted {
reason: ReportReasonCode,
},
Unavailable {
reason: ReportReasonCode,
},
}Expand description
Status for a workflow phase such as planning, loading, writing, or validation.
Variants
Completed
The phase completed successfully.
Failed
The phase failed.
Skipped
The phase was intentionally skipped.
Fields
reason: ReportReasonCodeStable reason code explaining why the phase was skipped.
NotStarted
The phase had not started.
Fields
reason: ReportReasonCodeStable reason code explaining why the phase did not start.
The phase status was unavailable.
Implementations
Sourceimpl PhaseStatus
impl PhaseStatus
Sourcepub fn to_json_value(self) -> Value
pub fn to_json_value(self) -> Value
Returns a JSON-compatible shape that preserves phase status kind and reason.
Sourceimpl PhaseStatus
impl PhaseStatus
Sourcepub const fn skipped(reason: ReportReasonCode) -> Self
pub const fn skipped(reason: ReportReasonCode) -> Self
Creates a skipped phase status with a stable reason code.
Sourcepub const fn not_started(reason: ReportReasonCode) -> Self
pub const fn not_started(reason: ReportReasonCode) -> Self
Creates a not-started phase status with a stable reason code.
Creates an unavailable phase status with a stable reason code.
Sourcepub const fn kind(&self) -> PhaseStatusKind
pub const fn kind(&self) -> PhaseStatusKind
Returns the phase status classification.
Sourcepub const fn reason(&self) -> Option<ReportReasonCode>
pub const fn reason(&self) -> Option<ReportReasonCode>
Returns the stable reason code when this status carries one.
Sourcepub const fn is_completed(&self) -> bool
pub const fn is_completed(&self) -> bool
Returns whether the phase completed successfully.
Sourcepub const fn is_skipped(&self) -> bool
pub const fn is_skipped(&self) -> bool
Returns whether the phase was skipped.
Sourcepub const fn is_not_started(&self) -> bool
pub const fn is_not_started(&self) -> bool
Returns whether the phase had not started.
Returns whether the phase status was unavailable.