pub enum SourceUsageStatus {
Used,
NotUsed,
Unknown,
}Expand description
Conservative source usage status for a workflow report.
Variants
Used
Source usage is known and the source was used by at least one selected output.
NotUsed
Source usage is known and the source was not used by selected outputs.
Unknown
Source usage could not be proven from available workflow analysis.
Implementations