pub enum TargetValidationMode {
Disabled,
ValidateIfPossible,
Require,
}Expand description
Controls whether target-side validation should run when a workflow supports it.
Variants
Disabled
Do not run target-side validation.
ValidateIfPossible
Run target-side validation when the selected workflow can do so.
Require
Require target-side validation and fail when it cannot be completed.
Implementations