pub enum ValidationStatusKind {
Disabled,
Passed,
Failed,
Skipped,
Unavailable,
RequiredButFailed,
}Expand description
Classification for target-side validation status.
Variants
Disabled
Validation was disabled by caller configuration.
Passed
Validation ran and passed.
Failed
Validation ran and failed.
Skipped
Validation did not run because it was intentionally skipped.
Validation could not run because required evidence was unavailable.
RequiredButFailed
Validation was required and could not pass.
Implementations