pub enum WriteAllNoCacheReason {
FewerThanTwoOutputs,
NoSharedRegisteredDerivedAlias,
AmbiguousSharedDerivedAlias,
}Expand description
Conservative reason no cache alias was selected for write_all.
Variants
FewerThanTwoOutputs
Cache selection only helps when at least two outputs use a candidate.
No registered derived alias is shared by at least two selected outputs.
Candidate relationships could not produce a deterministic cache frontier.