pub enum DeltaScanDeletionVectorPhase {
TableUriParsing,
ObjectStoreEngineConstruction,
DescriptorAccess,
PayloadRead,
SelectionVectorLengthMismatch,
SelectionVectorExhaustion,
}Expand description
Phase associated with a Delta scan deletion-vector failure.
Variants
TableUriParsing
Parsing the table URI failed.
ObjectStoreEngineConstruction
Constructing the kernel object-store engine failed.
DescriptorAccess
Accessing the preserved deletion-vector descriptor failed.
PayloadRead
Reading or decoding the deletion-vector payload failed.
SelectionVectorLengthMismatch
The selection vector did not match the physical file row count.
SelectionVectorExhaustion
The selection vector was consumed after it was closed.