pub enum DeltaScanFileReadPhase {
Show 13 variants
TableUriParsing,
FileMetadataConversion,
FilePathResolution,
ObjectStoreEngineConstruction,
ParquetReadSetup,
ParquetBatchRead,
RowIndexGeneration,
PredicateEvaluation,
ArrowConversion,
TransformApplication,
UnsupportedReadMode,
DeletionVectorPredicateRejection,
DeletionVectorMasking,
}Expand description
Phase associated with a Delta scan file read failure.
Variants
TableUriParsing
Parsing the table URI failed.
FileMetadataConversion
Converting provider file metadata into kernel file metadata failed.
FilePathResolution
Resolving the Delta add-action path against the table root failed.
ObjectStoreEngineConstruction
Constructing the kernel object-store engine failed.
ParquetReadSetup
Starting a Parquet read failed.
ParquetBatchRead
Reading a Parquet batch failed.
RowIndexGeneration
Generating or decoding original row indexes failed.
PredicateEvaluation
Evaluating a kernel physical predicate failed.
ArrowConversion
Converting kernel engine data into Arrow failed.
TransformApplication
Applying a physical-to-logical transform failed.
UnsupportedReadMode
The selected backend cannot read this file task equivalently.
DeletionVectorPredicateRejection
A deletion-vector read was rejected because the requested read mode is not safe.
DeletionVectorMasking
Applying a deletion-vector mask failed.