pub struct DeltaProviderSchedulingReport { /* private fields */ }Expand description
Configured provider scheduling options included with a Delta source report.
Implementations
Sourceimpl DeltaProviderSchedulingReport
impl DeltaProviderSchedulingReport
Sourcepub const fn query_target_partitions(&self) -> Option<u64>
pub const fn query_target_partitions(&self) -> Option<u64>
Returns the configured DataFusion target partition count, when set.
Sourcepub const fn reader_backend(&self) -> DeltaProviderReaderBackend
pub const fn reader_backend(&self) -> DeltaProviderReaderBackend
Returns the provider reader backend configured for source scans.
Sourcepub const fn max_concurrent_file_reads_per_scan(&self) -> Option<u64>
pub const fn max_concurrent_file_reads_per_scan(&self) -> Option<u64>
Returns the configured scan-wide file-read concurrency cap.
None means the cap is resolved during physical scan planning from the
derived scan partition target and the configured per-partition cap.
Sourcepub const fn max_concurrent_file_reads_per_partition(&self) -> u64
pub const fn max_concurrent_file_reads_per_partition(&self) -> u64
Returns the configured per-partition file-read concurrency cap.
Sourcepub const fn output_buffer_capacity_per_partition(&self) -> u64
pub const fn output_buffer_capacity_per_partition(&self) -> u64
Returns the configured per-partition provider output buffer capacity.
Sourcepub const fn native_async_prefetch_file_count_per_partition(&self) -> u64
pub const fn native_async_prefetch_file_count_per_partition(&self) -> u64
Returns the native async prefetch depth per execution partition.