DeltaTableProviderConfig

Struct DeltaTableProviderConfig 

pub struct DeltaTableProviderConfig {
    pub source: PlannedDeltaSource,
    pub protocol: ProtocolPreflight,
    pub scan_target_partitions: Option<usize>,
}
Delta source and preflight state used to build a DataFusion table provider.

Fields

source: PlannedDeltaSource

Loaded Delta source.

protocol: ProtocolPreflight

Successful Delta protocol preflight for the source.

scan_target_partitions: Option<usize>

Optional DeltaFunnel scan file task partition target override.

When set, this value wins over DataFusion’s session target and automatic machine fallback policy for this Delta source only.