pub struct MssqlPreparedTargetReport { /* private fields */ }Expand description
Redacted report for a prepared SQL Server target.
Implementations
Sourceimpl MssqlPreparedTargetReport
impl MssqlPreparedTargetReport
Sourcepub fn from_output_plan(
output_plan: &MssqlTargetOutputPlan,
action: MssqlPreparedTargetAction,
) -> Result<Self, DeltaFunnelError>
pub fn from_output_plan( output_plan: &MssqlTargetOutputPlan, action: MssqlPreparedTargetAction, ) -> Result<Self, DeltaFunnelError>
Builds a report from an already planned SQL Server output target.
Sourcepub fn output_name(&self) -> &str
pub fn output_name(&self) -> &str
Returns the selected output name.
Sourcepub const fn target_table(&self) -> &MssqlTargetTable
pub const fn target_table(&self) -> &MssqlTargetTable
Returns the effective target table.
Sourcepub const fn connection_source(&self) -> MssqlConnectionSource
pub const fn connection_source(&self) -> MssqlConnectionSource
Returns where the effective connection came from.
Sourcepub const fn connection(&self) -> &MssqlConnectionSummary
pub const fn connection(&self) -> &MssqlConnectionSummary
Returns the redacted effective connection summary.
Sourcepub const fn expected_target_state(&self) -> MssqlTargetTableState
pub const fn expected_target_state(&self) -> MssqlTargetTableState
Returns the expected live target table state before loading.
Sourcepub const fn action(&self) -> MssqlPreparedTargetAction
pub const fn action(&self) -> MssqlPreparedTargetAction
Returns the side effect completed while preparing the target.
Sourcepub const fn cleanup(&self) -> MssqlTargetCleanupStatus
pub const fn cleanup(&self) -> MssqlTargetCleanupStatus
Returns cleanup reporting state for DeltaFunnel-owned target cleanup.