pub struct MssqlWriteFailureReport { /* private fields */ }Expand description
Structured report for the first failed SQL Server output.
Implementations
Sourceimpl MssqlWriteFailureReport
impl MssqlWriteFailureReport
Sourcepub fn to_json_value(&self) -> Value
pub fn to_json_value(&self) -> Value
Returns one failed workflow output report as a JSON-compatible Python shape.
Sourceimpl MssqlWriteFailureReport
impl MssqlWriteFailureReport
Sourcepub const fn target(&self) -> &MssqlTargetSummary
pub const fn target(&self) -> &MssqlTargetSummary
Returns the redacted target summary for the failed output.
Sourcepub fn output_name(&self) -> &str
pub fn output_name(&self) -> &str
Returns the selected output name.
Sourcepub fn context(&self) -> Option<&MssqlWriteFailureContext>
pub fn context(&self) -> Option<&MssqlWriteFailureContext>
Returns phase-aware write failure context when the one-output sink provided it.
Sourcepub const fn output_row_count(&self) -> RowCount
pub const fn output_row_count(&self) -> RowCount
Returns query output row evidence known at failure time.
Sourcepub const fn target_row_count(&self) -> RowCount
pub const fn target_row_count(&self) -> RowCount
Returns target-side row count evidence known at failure time.
Sourcepub const fn validation_status(&self) -> ValidationStatus
pub const fn validation_status(&self) -> ValidationStatus
Returns target-side validation status known at failure time.
Sourcepub const fn batch_shaping(&self) -> MssqlBatchShapingReport
pub const fn batch_shaping(&self) -> MssqlBatchShapingReport
Returns batch-shaping counters known at failure time.
Sourcepub fn phase_timings(&self) -> &[PhaseTimingReport]
pub fn phase_timings(&self) -> &[PhaseTimingReport]
Returns workflow phase timing reports for this failed output.