pub struct MssqlWriteReport { /* private fields */ }Expand description
Redacted per-output SQL Server write report.
Implementations
Sourceimpl MssqlWriteReport
impl MssqlWriteReport
Sourcepub fn to_json_value(&self) -> Value
pub fn to_json_value(&self) -> Value
Returns the execute output report as a JSON-compatible Python shape.
Sourceimpl MssqlWriteReport
impl MssqlWriteReport
Sourcepub fn from_output_plan(
output_plan: &MssqlTargetOutputPlan,
rows_written: u64,
batches_written: u64,
elapsed_ms: u64,
partial_write_possible: bool,
cleanup: MssqlTargetCleanupStatus,
) -> Self
pub fn from_output_plan( output_plan: &MssqlTargetOutputPlan, rows_written: u64, batches_written: u64, elapsed_ms: u64, partial_write_possible: bool, cleanup: MssqlTargetCleanupStatus, ) -> Self
Builds a write report from the already planned SQL Server output target.
Sourcepub fn output_name(&self) -> &str
pub fn output_name(&self) -> &str
Returns the selected output name.
Sourcepub fn target_table(&self) -> &MssqlTargetTable
pub fn target_table(&self) -> &MssqlTargetTable
Returns the effective target table.
Sourcepub const fn connection_source(&self) -> MssqlConnectionSource
pub const fn connection_source(&self) -> MssqlConnectionSource
Returns where the effective connection came from.
Sourcepub const fn connection(&self) -> &MssqlConnectionSummary
pub const fn connection(&self) -> &MssqlConnectionSummary
Returns the redacted effective connection summary.
Sourcepub const fn stats(&self) -> &MssqlWriteStats
pub const fn stats(&self) -> &MssqlWriteStats
Returns per-output write statistics.
Sourcepub fn output_schema(&self) -> &[MssqlOutputFieldReport]
pub fn output_schema(&self) -> &[MssqlOutputFieldReport]
Returns the selected output schema fields.
Sourcepub const fn output_row_count(&self) -> RowCount
pub const fn output_row_count(&self) -> RowCount
Returns query output row evidence for the selected output stream.
Sourcepub const fn target_row_count(&self) -> RowCount
pub const fn target_row_count(&self) -> RowCount
Returns target-side row count evidence after the SQL Server write.
Sourcepub const fn target_row_count_before_write(&self) -> RowCount
pub const fn target_row_count_before_write(&self) -> RowCount
Returns target-side row count evidence before the SQL Server write. For append-existing validation, concurrent target writes can affect the row-count delta.
Sourcepub const fn target_row_count_after_write(&self) -> RowCount
pub const fn target_row_count_after_write(&self) -> RowCount
Returns target-side row count evidence after the SQL Server write. For append-existing validation, concurrent target writes can affect the row-count delta.
Sourcepub const fn validation_status(&self) -> ValidationStatus
pub const fn validation_status(&self) -> ValidationStatus
Returns target-side validation status for this output.
Sourcepub const fn batch_shaping(&self) -> MssqlBatchShapingReport
pub const fn batch_shaping(&self) -> MssqlBatchShapingReport
Returns identity batch-shaping counters for the selected output stream.
Sourcepub fn phase_timings(&self) -> &[PhaseTimingReport]
pub fn phase_timings(&self) -> &[PhaseTimingReport]
Returns workflow phase timing reports for this output when available.
Sourcepub const fn partial_write_possible(&self) -> bool
pub const fn partial_write_possible(&self) -> bool
Returns whether the target may contain a partial write after failure.
Sourcepub const fn cleanup(&self) -> MssqlTargetCleanupStatus
pub const fn cleanup(&self) -> MssqlTargetCleanupStatus
Returns cleanup reporting state for DeltaFunnel-owned target cleanup.