pub struct OutputWritePlan { /* private fields */ }Expand description
Planned output write request before schema planning or execution.
Implementations
Sourceimpl OutputWritePlan
impl OutputWritePlan
Sourcepub const fn new(table: LazyTable, target: MssqlOutputTarget) -> Self
pub const fn new(table: LazyTable, target: MssqlOutputTarget) -> Self
Creates an output write request for a lazy table.
Sourcepub const fn target(&self) -> &MssqlOutputTarget
pub const fn target(&self) -> &MssqlOutputTarget
Returns the selected MSSQL output target.