pub struct ResolvedMssqlTarget { /* private fields */ }Expand description
Resolved SQL Server target for one selected output.
Implementations
Sourceimpl ResolvedMssqlTarget
impl ResolvedMssqlTarget
Sourcepub fn output_name(&self) -> &str
pub fn output_name(&self) -> &str
Returns the selected output name associated with this target.
Sourcepub fn table(&self) -> &MssqlTargetTable
pub fn table(&self) -> &MssqlTargetTable
Returns the target table identity.
Sourcepub fn connection(&self) -> &MssqlConnectionConfig
pub fn connection(&self) -> &MssqlConnectionConfig
Returns the effective connection.
Sourcepub fn connection_source(&self) -> MssqlConnectionSource
pub fn connection_source(&self) -> MssqlConnectionSource
Returns where the effective connection came from.
Sourcepub fn summary(&self) -> MssqlTargetSummary
pub fn summary(&self) -> MssqlTargetSummary
Returns a redacted planning summary for diagnostics and Python-facing reports.